<?xml version="1.0" encoding="utf-8" ?>
<!-- 
graphein-tohtml.xsl
Version 0.0
"graphein" Tools
See http://www.CircuitousRoot.com/graphein/ for documentation.

Copyright 2006 by David M. MacMillan and Rollande Krandall.

This work is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
   
You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place, Suite 330
Boston, MA  02111-1307
USA

Circuitous Root is a trademark of David M. MacMillan and Rollande Krandall

Presented originally by Circuitous Root. http://www.CircuitousRoot.com/


XSLT to Transform TEI to XHTML
Requires:    A CSS stylesheet
             TEI P5 encoded source
                Attribute convensions as discussed in the graphein documents
             XSLT 1.1 compliant processor
Parameters:  required: base name of a CSS stylesheet
Outputs:     XHTML 1.0
Tested with: Saxon 6.5.3
-->

<xsl:stylesheet 
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:tei="http://www.tei-c.org/ns/1.0"
   version="1.1">

<!-- ========== -->
<!-- Parameters -->
<!-- ========== -->
<xsl:param name="css-basename" />

<!-- ================= -->
<!-- XSL Configuration -->
<!-- ================= -->
<xsl:output method="xml"
            encoding="utf-8" />

<!-- Suppress inter-tag whitespace in output. -->
<!-- (Do output prettyprinting explicitly, adding #xA (linefeed) entities
     and spaces explicitly in xsl:text.) -->
<xsl:strip-space elements="*" />
<!-- note: opposite is xsl:preserve-space -->


<!-- ================== -->            <!--  /  -->
<!-- root and TEI nodes -->            <!--  |  -->
<!-- ================== -->            <!-- TEI -->
<xsl:template match="/">  <!-- yes, this is redundant -->
   <xsl:apply-templates/>
</xsl:template>

<xsl:template match="tei:TEI">
   <xsl:text>&#xA;</xsl:text>
   <html>
      <xsl:apply-templates/>
   <xsl:text>&#xA;</xsl:text>
   </html>
</xsl:template>

<!-- ============= -->                 <!-- TEI              -->
<!-- TEI teiHeader -->                 <!--  |.... teiHeader -->
<!-- ============= -->                 <!--  |.... text      -->
<xsl:template match="tei:teiHeader">
   <xsl:text>&#xA;</xsl:text>
   <head>
      <xsl:text>&#xA;</xsl:text>
      <title>
         <xsl:value-of select="//tei:title" />
      </title>
      <xsl:text>&#xA;</xsl:text>
      <link>
         <xsl:attribute name="rel">stylesheet</xsl:attribute>
         <xsl:attribute name="type">text/css</xsl:attribute>
         <xsl:attribute name="media">screen</xsl:attribute>
         <xsl:attribute name="title">
            <xsl:value-of select="$css-basename" />
         </xsl:attribute>
         <xsl:attribute name="href">
            <xsl:value-of select="$css-basename"/>
            <xsl:text>.css</xsl:text>
         </xsl:attribute>
      </link>

   <xsl:text>&#xA;</xsl:text>
   </head>
</xsl:template>

<!-- suppress other teiHeader stuff -->
<xsl:template match="tei:fileDesc"></xsl:template>
<xsl:template match="tei:editionStmt"></xsl:template>
<xsl:template match="tei:publicationStmt"></xsl:template>
<xsl:template match="tei:sourceDesc"></xsl:template>
<xsl:template match="tei:revisionDesc"></xsl:template>

<!-- ============= -->                 <!-- text ......front -->
<!-- TEI text Node -->                 <!--        |...body  -->
<!-- ============= -->                 <!--        |...back  -->
<xsl:template match="tei:text">
   <xsl:text>&#xA;</xsl:text>
   <body>
      <xsl:apply-templates/>
   <xsl:text>&#xA;</xsl:text>
   <xsl:call-template name="legal-matters" />
   <xsl:text>&#xA;</xsl:text>
   </body>
</xsl:template>

<!-- ================ -->
<!-- TEI Front Matter -->
<!-- ================ -->
<xsl:template match="tei:front">
   <xsl:apply-templates/>
</xsl:template>

<xsl:template match="tei:docTitle">
   <xsl:apply-templates/>
</xsl:template>

<xsl:template match="tei:titlePart[@type='main']">
   <xsl:text>&#xA;</xsl:text>
   <xsl:text>&#xA;</xsl:text>
   <h1 class="main">
      <xsl:value-of select="." />
   </h1>
</xsl:template>

<xsl:template match="tei:titlePart[@type='sub']">
   <xsl:text>&#xA;</xsl:text>
   <xsl:text>&#xA;</xsl:text>
   <h1 class="sub">
      <xsl:value-of select="." />
   </h1>
</xsl:template>

<!-- Grab the contents of the teiHeader publicationStmt availability section,
     format it for the "legal matters" div, and put it whereever this
     template is called from (right before the close of the body,
     as it will happen. -->
<xsl:template name="legal-matters">
   <xsl:text>&#xA;</xsl:text>
   <div class="legal-matters">
      <xsl:apply-templates select="//tei:availability"/>
   <xsl:text>&#xA;</xsl:text>
   </div>
</xsl:template>

<xsl:template match="tei:ab[@type='legal-item-pd']">
   <xsl:text>&#xA;</xsl:text>
   <p>
      <xsl:apply-templates/>
   </p>
</xsl:template>

<xsl:template name="pd-disclaimers">
   <strong>
   <a href="http://www.circuitousroot.com/pd-disclaimers.html">Important 
   disclaimers of warranty and liability in the presentation 
   of public domain material</a>.
   </strong>
</xsl:template>

<!-- ======== -->
<!-- TEI Body -->
<!-- ======== -->

<xsl:template match="tei:div[@type='section']">
   <xsl:text>&#xA;</xsl:text>
   <xsl:text>&#xA;</xsl:text>
   <h2>
   <a name="{generate-id(.)}">
   <xsl:number level="multiple" count="tei:div" format="1.1. "/>
   <xsl:value-of select="tei:head" />
   </a>
   </h2>
   <xsl:apply-templates />
</xsl:template>

<!-- This is null because we pick up the traversal of tei:head
     in the tei:div[@type='section'] template, above. -->
<xsl:template match="tei:head"></xsl:template>


<xsl:template match="tei:p">
   <xsl:text>&#xA;</xsl:text>
   <p>
   <xsl:apply-templates/>
   </p>
</xsl:template>

<xsl:template match="tei:list">
   <xsl:text>&#xA;</xsl:text>
   <ul>
   <xsl:apply-templates/>
   </ul>
</xsl:template>

<xsl:template match="tei:item">
   <xsl:text>&#xA;</xsl:text>
   <li><xsl:apply-templates/></li>
</xsl:template>

<xsl:template match="tei:title">
   <i><xsl:apply-templates/></i>
</xsl:template>

<!-- =============== -->
<!-- TEI Back Matter -->
<!-- =============== -->

</xsl:stylesheet>

<!--
This work is licensed under the Creative Commons Attribution-ShareAlike License.
To view a copy of this license,
visit http://creativecommons.org/licenses/by-sa/2.0/
or send a letter to
Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.

Presented originally by circuitousroot.com [SM]: http://www.circuitousroot.com/
-->

