<?xml version="1.0" encoding="utf-8" ?>
<!-- 
graphein-tonotangle.xsl
Version 0.0
"graphein" Tools
See http://www.CircuitousRoot.com/graphein/ for documentation.

Copyright 2006-2008 by David M. MacMillan and Rollande Krandall.

This work is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
   
You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place, Suite 330
Boston, MA  02111-1307
USA

Circuitous Root is a registered trademark of David M. MacMillan and 
Rollande Krandall

Presented originally by Circuitous Root (R). http://www.CircuitousRoot.com/


XSLT to extract TEI-encoded noweb-style code chunks from graphein TEI source
and output them in noweb (notangle) syntax.

Requires:    TEI P5 encoded source
                Attribute convensions as discussed in the graphein documents
             XSLT 1.1 compliant processor
Parameters:  none
Outputs:     noweb-syntax code chunks
Tested with: Saxon 6.5.3
-->

<xsl:stylesheet 
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:tei="http://www.tei-c.org/ns/1.0"
   version="1.1">

<!-- ========== -->
<!-- Parameters -->
<!-- ========== -->
<!-- none -->

<!-- ================= -->
<!-- XSL Configuration -->
<!-- ================= -->
<xsl:output method="text"
            encoding="utf-8" />

<!-- Suppress inter-tag whitespace in output. -->
<!-- (Do output prettyprinting explicitly, adding #xA (linefeed) entities
     and spaces explicitly in xsl:text.) -->
<xsl:strip-space elements="*" />
<!-- note: opposite is xsl:preserve-space -->


<!-- ================== -->            <!--  /  -->
<!-- root and TEI nodes -->            <!--  |  -->
<!-- ================== -->            <!-- TEI -->
<xsl:template match="/">  <!-- yes, this is redundant -->
   <xsl:apply-templates/>
</xsl:template>

<xsl:template match="tei:TEI">
   <xsl:text>&#xA;</xsl:text>
   <html>
      <xsl:apply-templates/>
   <xsl:text>&#xA;</xsl:text>
   </html>
</xsl:template>

<!-- ============= -->                 <!-- TEI              -->
<!-- TEI teiHeader -->                 <!--  |.... teiHeader -->
<!-- ============= -->                 <!--  |.... text      -->
<xsl:template match="tei:teiHeader"></xsl:template>

<!-- ============= -->                 <!-- text ......front -->
<!-- TEI text Node -->                 <!--        |...body  -->
<!-- ============= -->                 <!--        |...back  -->
<xsl:template match="tei:text">
   <xsl:apply-templates/>
</xsl:template>

<xsl:template match="tei:body">
   <body>
      <xsl:apply-templates/>
   </body>
</xsl:template>

<!-- ================ -->
<!-- TEI Front Matter -->
<!-- ================ -->
<xsl:template match="tei:front"></xsl:template>

<!-- ======== -->
<!-- TEI Body -->
<!-- ======== -->

<xsl:template match="tei:div">
   <xsl:apply-templates />
</xsl:template>

<xsl:template match="tei:head"></xsl:template>

<xsl:template match="tei:bibl"></xsl:template>

<xsl:template match="tei:p"></xsl:template>

<xsl:template match="tei:list"></xsl:template>

<xsl:template match="tei:table"></xsl:template>

<xsl:template match="tei:figure"></xsl:template>

<!-- =============================== -->
<!-- Minimalist Literate Programming -->
<!-- =============================== -->
<!-- Note: The run-on line in the PRE definition is important for avoiding
           extra space in the output. 
           The flush-leftness of the line is also important for avoiding
           extra space before the noweb opening double angle bracket.  -->
<xsl:template match="tei:ab[@type='code-chunk']">
   <xsl:text>&#xA;</xsl:text>
&lt;&lt;<xsl:value-of select="@xml:id" />&gt;&gt;=<xsl:apply-templates/>
</xsl:template>

<xsl:template match="tei:seg[@type='code-chunk-ref']">&lt;&lt;<xsl:apply-templates/>&gt;&gt;</xsl:template>

<xsl:template match="tei:ab"></xsl:template>


<!-- =============== -->
<!-- TEI Back Matter -->
<!-- =============== -->
<xsl:template match="tei:back"></xsl:template>


</xsl:stylesheet>

